Package: VGAM
Version: 1.0-3
Date: 2017-01-11
Title: Vector Generalized Linear and Additive Models
Author: Thomas W. Yee <t.yee@auckland.ac.nz>
Maintainer: Thomas Yee <t.yee@auckland.ac.nz>
Depends: R (>= 3.1.0), methods, stats, stats4, splines
Suggests: VGAMdata, MASS, mgcv
Description: An implementation of about 6 major classes of
    statistical regression models. At the heart of it are the
    vector generalized linear and additive model (VGLM/VGAM)
    classes, and the book "Vector Generalized Linear and
    Additive Models: With an Implementation in R" (Yee, 2015)
    <DOI:10.1007/978-1-4939-2818-7>
    gives details of the statistical framework and VGAM package.
    Currently only fixed-effects models are implemented,
    i.e., no random-effects models. Many (150+) models and
    distributions are estimated by maximum likelihood estimation
    (MLE) or penalized MLE, using Fisher scoring. VGLMs can be
    loosely thought of as multivariate GLMs. VGAMs are data-driven
    VGLMs (i.e., with smoothing). The other classes are RR-VGLMs
    (reduced-rank VGLMs), quadratic RR-VGLMs, reduced-rank VGAMs,
    RCIMs (row-column interaction models)---these classes perform
    constrained and unconstrained quadratic ordination (CQO/UQO)
    models in ecology, as well as constrained additive ordination
    (CAO). Note that these functions are subject to change;
    see the NEWS and ChangeLog files for latest changes.
License: GPL-2 | GPL-3
URL: https://www.stat.auckland.ac.nz/~yee/VGAM
NeedsCompilation: yes
BuildVignettes: yes
LazyLoad: yes
LazyData: yes
Packaged: 2017-01-11 02:07:28 UTC; tyee001
Repository: CRAN
Date/Publication: 2017-01-11 08:59:31
Built: R 3.3.2; x86_64-w64-mingw32; 2017-04-24 09:37:39 UTC; windows
Archs: x64
