Package: VGAM
Version: 1.1-12
Date: 2024-09-18
Title: Vector Generalized Linear and Additive Models
Authors@R: c(person("Thomas", "Yee", role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0002-9970-3907"),
                    email = "t.yee@auckland.ac.nz"),
             person("Cleve", "Moler", role = "ctb",
                    comment = "LINPACK routines in src"))
Author: Thomas Yee [aut, cre] (<https://orcid.org/0000-0002-9970-3907>),
  Cleve Moler [ctb] (LINPACK routines in src)
Maintainer: Thomas Yee <t.yee@auckland.ac.nz>
Depends: R (>= 4.1.0), methods, stats, stats4, splines
Suggests: VGAMextra, MASS, mgcv
Enhances: VGAMdata
Description: An implementation of about 6 major classes of
    statistical regression models. The central algorithm is
    Fisher scoring and iterative reweighted least squares.
    At the heart of this package are the vector generalized linear
    and additive model (VGLM/VGAM) classes. VGLMs can be loosely
    thought of as multivariate GLMs. VGAMs are data-driven
    VGLMs that use smoothing. The book "Vector Generalized
    Linear and Additive Models: With an Implementation in R"
    (Yee, 2015) <DOI:10.1007/978-1-4939-2818-7> gives details of
    the statistical framework and the package. Currently only
    fixed-effects models are implemented. Many (100+) models and
    distributions are estimated by maximum likelihood estimation
    (MLE) or penalized MLE. The other classes are RR-VGLMs
    (reduced-rank VGLMs), quadratic RR-VGLMs, doubly constrained
    RR-VGLMs, quadratic RR-VGLMs, reduced-rank VGAMs,
    RCIMs (row-column interaction models)---these classes perform
    constrained and unconstrained quadratic ordination (CQO/UQO)
    models in ecology, as well as constrained additive ordination
    (CAO). Hauck-Donner effect detection is implemented.
    Note that these functions are subject to change;
    see the NEWS and ChangeLog files for latest changes.
License: GPL-3
URL: https://www.stat.auckland.ac.nz/~yee/VGAM/
NeedsCompilation: yes
BuildVignettes: yes
LazyLoad: yes
LazyData: yes
Packaged: 2024-09-18 02:04:29 UTC; tyee001
Repository: CRAN
Date/Publication: 2024-09-18 07:20:10 UTC
Built: R 4.6.0; armv7--netbsdelf-eabihf; 2026-08-09 14:55:48 UTC; unix
